@@ -23,6 +23,7 @@ class TestJsonnet:
 
 
 class TestDockerJsonnet:
+    @pytest.mark.skipif("os.name == 'nt'")
     def test_named_user_group(self, project_loader):
         project_loader("named-user-group")
 
@@ -42,3 +43,17 @@ class TestDockerJsonnet:
 
         with pytest.raises(RuntimeError):
             main(["configure"])
+
+    def test_binary(self, project_loader):
+        project_loader("jsonnet-binary")
+
+        main(["configure"])
+
+        assert os.path.exists('docker-compose.yml')
+        with open('docker-compose.yml', 'r') as f:
+            docker_compose = yaml.load(f, yaml.SafeLoader)
+
+        with open('docker-compose.expected.yml', 'r') as f:
+            docker_compose_expected = yaml.load(f, yaml.SafeLoader)
+
+        assert docker_compose == docker_compose_expected
